#
# spec file for package python-numpy
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define with_atlas 0

%define modname numpy
Name:           python-%{modname}
Version:        1.8.0
Release:        4.17
Url:            http://sourceforge.net/projects/numpy
Summary:        NumPy array processing for numbers, strings, records and objects
License:        BSD-3-Clause
Group:          Development/Libraries/Python
Source:         http://sourceforge.net/projects/numpy/files/NumPy/%{version}/%{modname}-%{version}.tar.gz
Patch0:         numpy-buildfix.patch
Patch1:         numpy-double-double-le.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  blas-devel
BuildRequires:  lapack-devel
BuildRequires:  python-devel >= 2.6
Requires:       python >= %{py_ver}
Provides:       numpy = %{version}
%if %{with_atlas} == 1
BuildRequires:  libatlas3-devel
%endif
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  gcc-fortran
%if 0%{?suse_version} <= 1110
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
%else
%py_requires
%endif
%else
BuildRequires:  gcc-gfortran
%if ! 0%{?fedora_version}
Provides:       python-numeric = %{version}
Obsoletes:      python-numeric < %{version}
%endif
%endif

%description
NumPy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays.  NumPy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type which also makes NumPy suitable for
interfacing with general-purpose data-base applications.

There are also basic facilities for discrete fourier transform,
basic linear algebra and random number generation.

%package devel
Summary:        Development files for %{modname} applications
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       blas-devel
Requires:       lapack-devel
Requires:       python-devel >= %{py_ver}
%if 0%{?suse_version}
Requires:       gcc-fortran
%py_requires -d
%else
Requires:       gcc-gfortran
%endif
%if %{with_atlas} == 1
Requires:       libatlas3-devel
%endif

%description devel
This package contains files for developing applications using %{modname}.

%prep
%setup -q -n %{modname}-%{version}
%patch0 -p1
%patch1
# Fix non-executable scripts
sed -i "1d" numpy/{compat/setup,distutils/{conv_template,cpuinfo,exec_command,from_template,setup,system_info},f2py/{auxfuncs,capi_maps,cb_rules,cfuncs,common_rules,crackfortran,diagnose,docs/usersguide/setup_example,f2py2e,f90mod_rules,func2subr,__init__,rules,setup,use_rules},ma/setup,matrixlib/setup,setup,testing/{print_coercion_tables,setup}}.py

%build
CFLAGS="%{optflags} -fno-strict-aliasing" python setup.py build

%install
python setup.py install --root="%{buildroot}" --prefix="%{_prefix}"
rm -rf %{buildroot}%{python_sitearch}/%{modname}/{,core,distutils,f2py,fft,ma,matrixlib,oldnumeric,polynomial,random,testing}/tests # Don't package testsuite
%if 0%{?suse_version}
%fdupes -s %{buildroot}%{_prefix}
%endif

%files
%defattr(-,root,root)
%doc *.txt
%{_bindir}/f2py
%{python_sitearch}/%{modname}/
%{python_sitearch}/%{modname}-%{version}-py%{py_ver}.egg-info
%exclude %{python_sitearch}/%{modname}/*/*/*.c
%exclude %{python_sitearch}/%{modname}/*/*.h
%exclude %{python_sitearch}/%{modname}/*/*/*.h
%exclude %{python_sitearch}/%{modname}/*/*/*/*.h
%exclude %{python_sitearch}/%{modname}/core/lib/libnpymath.a

%files devel
%defattr(-,root,root)
%{python_sitearch}/%{modname}/*/*/*.c
%{python_sitearch}/%{modname}/*/*.h
%{python_sitearch}/%{modname}/*/*/*.h
%{python_sitearch}/%{modname}/*/*/*/*.h
%{python_sitearch}/%{modname}/core/lib/libnpymath.a

%changelog
* Thu Dec  5 2013 mls@suse.de
- add numpy-double-double-le.patch for ppc64le
* Thu Oct 31 2013 toddrme2178@gmail.com
- Update to 1.8.0
  Highlights:
  * New, no 2to3, Python 2 and Python 3 are supported by a common code base.
  * New, gufuncs for linear algebra, enabling operations on stacked arrays.
  * New, inplace fancy indexing for ufuncs with the ``.at`` method.
  * New, ``partition`` function, partial sorting via selection for fast median.
  * New, ``nanmean``, ``nanvar``, and ``nanstd`` functions skipping NaNs.
  * New, ``full`` and ``full_like`` functions to create value initialized arrays.
  * New, ``PyUFunc_RegisterLoopForDescr``, better ufunc support for user dtypes.
  * Numerous performance improvements in many areas.
- Add a new flag to easily enable/disable atlas support for if it
  ever gets fixed in the future
- Rebase numpy-buildfix.patch
* Fri May  3 2013 toddrme2178@gmail.com
- Update to 1.7.1
  * Bugfixes
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Tue Mar 12 2013 highwaystar.ru@gmail.com
- update to 1.7.0
  * This release includes several new features as well as numerous
  bug fixes and refactorings
  Highlights:
  - ``where=`` parameter to ufuncs (allows the use of boolean
  arrays to choose where a computation should be done)
  - ``vectorize`` improvements (added 'excluded' and 'cache'
  keyword, general cleanup and bug fixes)
  - ``numpy.random.choice`` (random sample generating function)
  New Features:
  - Reduction UFuncs Generalize axis= Parameter
  - Reduction UFuncs New keepdims= Parameter
  - Datetime support
  - Custom formatter for printing arrays
  - New function numpy.random.choice
  - New function isclose
  - Preliminary multi-dimensional support in the polynomial package
  - Ability to pad rank-n arrays
  - New argument to searchsorted
  - Added experimental support for the AArch64 architecture.
  * For additional details check release notes at
  http://sourceforge.net/projects/numpy/files/NumPy/1.7.0/
- numpy-aarch64.diff: removed, now upstream
* Tue Mar  5 2013 dmueller@suse.com
- add numpy-aarch64.diff:
  * Fix build for AArch64
* Fri Aug 17 2012 toddrme2178@gmail.com
- Disable atlas buildrequires until the problems with atlas are
  worked out
* Mon Jun  4 2012 toddrme2178@gmail.com
- Add libatlas2 buildrequires
* Fri Jun  1 2012 toddrme2178@gmail.com
- Remove blas/lapack tests since these build successfully on all
  targets now
- Add documentation packages
  These are separate packages because a lot of packages depend on
  numpy, so building the documentation inside the base spec file
  would slow down the build process for the entire project
* Fri Jun  1 2012 kukuk@suse.de
- Old products don't provide python(abi).
* Mon May 21 2012 toddrme2178@gmail.com
- Update to version 1.6.2:
  * bugfixes
* Fri May 18 2012 toddrme2178@gmail.com
- Fix rpmlint warnings
* Mon Apr 30 2012 toddrme2178@gmail.com
- Removed tests for unsupported openSUSE versions
* Mon Apr 23 2012 toddrme2178@gmail.com
- Add python 3 package
- devel package BuildRequires -> Requires
* Sun Apr 15 2012 idonmez@suse.com
- Fix SLE_11 build
* Fri Apr 13 2012 badshah400@gmail.com
- Modify BuildRequires to match recent name changes of lapack and
  blas in project.
* Sat Oct  1 2011 behrisch@users.sf.net
- Added static lib to devel package for scipy build
* Wed Sep 21 2011 saschpe@suse.de
- Update to version 1.6.1:
  * Please see http://downloads.sourceforge.net/project/numpy/NumPy/1.6.1/Changelog
- Spec file cleanup:
  * Set license to BSD-3-Clause (SPDX style)
  * Removed testsuite from packages
  * Removed rpmlintrc file and actually fixed the issues
* Sun Jan 23 2011 toddrme2178@gmail.com
- update to 1.5.1
  Numpy 1.5.1 is a bug-fix release with no new
  features compared to 1.5.0.
  Relevant bugs fixed:
  * linalg: lstsq should always return real residual
  * lib: fix negative indices in s_ and index_exp
  * core: fix uint64 -> Python int cast
  * core: richcompare should return Py_NotImplemented when undefined
  * lib: close file handles after use in numpy.lib.npyio.*
  * core: ensure PEP 3118 buffers can be released in exception handler
  * core: fix clongdouble cast to Python complex()
  * core: fix detection for ``isfinite`` routine
* Mon Sep  6 2010 coolo@novell.com
- update to 1.5.0 to fix build against python 2.7
  highlights 1.3 -> 1.4:
  * New datetime dtype support to deal with dates in arrays
  * Faster import time
  * Extended array wrapping mechanism for ufuncs
  * New Neighborhood iterator (C-level only)
  * C99-like complex functions in npymath
  highlights 1.4 -> 1.5:
  * support for python3 and python 2.7
* Mon May 31 2010 bg@novell.com
- fix build for hppa
* Fri Jan 15 2010 aeszter@gwdg.de
- re-enable build on non-SUSE distros
- do not provide python-numeric on Fedora, since a package by that
  name exists
* Wed Jan 13 2010 lars@linux-schulserver.de
- use a more generic way to define py_sitedir on all targets
* Mon Jan 11 2010 coolo@novell.com
- remerge d:l:p version with O:F version
  - split -devel package and add support for !suse targets
* Wed Apr  8 2009 matejcik@suse.cz
- update to 1.3.0
  * official python 2.6 support (although it did (mostly)
    work before)
  * new multiarray APIs
* Wed Feb 11 2009 ro@suse.de
- fix filelist by using "--record-rpm" instead of "--record"
  (and do not quote lines starting with "%%dir ")
* Wed Feb  4 2009 matejcik@suse.cz
- package taken directly from devel:languages:python repository,
  original changelog follows:
* Tue Dec  2 2008 James Oakley <jfunk@funktronics.ca> - 1.2.1-1
- Update to 1.2.1
* Mon Aug 11 2008 James Oakley <jfunk@funktronics.ca> - 1.1.1-1
- Update to 1.1.1:
  - Python 2.3.x fixes
  * Robert Kern -- remove development branch of f2py.
  * Pierre GM -- masked array, fix dictionary update.
  * Pierre GM -- masked array, fix itertools groupby dependency.
  * Pierre GM -- masked array, fix use of iterators.
  * Neil Muller -- fix test dependency on pretty print (#828).
  - General improvements
  * David Cournapeau -- scons build fixes/improvements.
  * Stefan van der Walt -- Howto document updates.
  * Fernando Perez -- cython updates.
  * Robert Kern -- PyPI metadata fixes.
  - Bug fixes
  * #791 -- Travis Oliphant, std/var not properly calling array_finalize.
  * #798 -- Stefan van der Walt, piecewise exposes raw memory.
  * #810 -- David Huard, Verbose argument not effective for ndarrays in assert_equal.
  * #828 -- Neil Muller, numpy file format format test failures on Solaris.
  * #825 -- Neil Muller/Charles Harris, SIGBUS in UNICODE_getattr on Sparc Linux.
  * #837 -- Pauli Virtanen, Infinite loop in fromfile & fromstring
  * #841 -- Charles Harris, make numpy complex types print like Python.
  * #843 -- Michael Abbott, reference count error in PyArray_CanCoerceScalar
  * #844 -- David Cournapeau, failure with numpy inner.
  * #848 -- Michael Abbott/Charles Harris/Travis Oliphant, reference leak.
  * #849 -- Michael Abbott, reference to deallocated object.
  * #850 -- Michael Abbott, memory leak.
  * #854 -- Pauli Virtanen, Non-standard branch cuts (arccosh).
  * #857 -- Pierre GM, dividing masked array with newaxis fails.
  * ------- David Cournapeau, ctypes load_library fix.
  * ------- Ryan May, Stefan van der Walt, fix loadtxt.
  * ------- Robert Kern, make numeric.py functions return booleans.
  * ------- Robert Kern, correct old numeric typecodes.
  * ------- Robert Kern, fix raising exception in tests.
  * ------- Robert Kern, make sure Zipf results are in allowable range.
  * ------- Robert Kern, fix c++ style comment.
